==> app-1.1.2-sources.jar: com/redking/view/activity/X5MainActivity.java <==
package com.redking.view.activity;

import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
import android.support.annotation.Nullable;
import android.view.View;

import com.redking.util.InitX5;
import com.redking.x5.R;

/**
 * Created by redking on 2018/8/18.
 */

public class X5MainActivity extends Activity{

    @Override
    protected void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.red_act_main);
        //调用该方法初始化X5内核
        InitX5.initX5(this);
        //.pdf文档
        findViewById(R.id.btn_pdf).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                startActivity(new Intent(X5MainActivity.this, DocOpenDemoActivity.class).putExtra("fileUrl", "http://sources.ikeepstudying.com/jquery.media/guice.pdf"));
            }
        });
        //.doc,.docs文档
        findViewById(R.id.btn_doc).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                startActivity(new Intent(X5MainActivity.this, DocOpenDemoActivity.class).putExtra("fileUrl", "http://www.xdocin.com/demo/demo.docx"));
            }
        });
        //.xls,.xlsx文档
        findViewById(R.id.btn_excel).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                startActivity(new Intent(X5MainActivity.this, DocOpenDemoActivity.class).putExtra("fileUrl", "http://storage.xuetangx.com/public_assets/xuetangx/PDF/1.xls"));
            }
        });

        //.xls,.xlsx文档
        findViewById(R.id.btn_ppt).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                startActivity(new Intent(X5MainActivity.this, DocOpenDemoActivity.class).putExtra("fileUrl", "http://video.ch9.ms/build/2011/slides/TOOL-532T_Sutter.pptx"));
            }
        });
        //视频
        findViewById(R.id.btn_video).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                startActivity(new Intent(X5MainActivity.this, VideoPlayDemoActivity.class));
            }
        });

    }
}

==> app-1.1.3-sources.jar: com/redking/view/activity/X5MainActivity.java <==
package com.redking.view.activity;

import android.app.Activity;
import android.content.Intent;
import android.graphics.Matrix;
import android.os.Bundle;
import android.support.annotation.Nullable;
import android.view.View;
import android.widget.Button;

import com.redking.util.InitX5;
import com.redking.x5.R;

/**
 * Created by redking on 2018/8/18.
 */

public class X5MainActivity extends Activity{

    @Override
    protected void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.red_act_main);
        //调用该方法初始化X5内核
        InitX5.initX5(this);
        //.pdf文档
        findViewById(R.id.btn_pdf).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                startActivity(new Intent(X5MainActivity.this, DocOpenDemoActivity.class).putExtra("fileUrl", "https://www.kotlincn.net/docs/kotlin-docs.pdf"));
            }
        });
        //.doc,.docs文档
        findViewById(R.id.btn_doc).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                startActivity(new Intent(X5MainActivity.this, DocOpenDemoActivity.class).putExtra("fileUrl", "http://www.xdocin.com/demo/demo.docx"));
            }
        });
        //.xls,.xlsx文档
        findViewById(R.id.btn_excel).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                startActivity(new Intent(X5MainActivity.this, DocOpenDemoActivity.class).putExtra("fileUrl", "http://storage.xuetangx.com/public_assets/xuetangx/PDF/1.xls"));
            }
        });

        //.xls,.xlsx文档
        findViewById(R.id.btn_ppt).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                startActivity(new Intent(X5MainActivity.this, DocOpenDemoActivity.class).putExtra("fileUrl", "http://video.ch9.ms/build/2011/slides/TOOL-532T_Sutter.pptx"));
            }
        });
        //视频
        findViewById(R.id.btn_video).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                startActivity(new Intent(X5MainActivity.this, VideoPlayDemoActivity.class));
            }
        });
//        Button btn_excel = (Button) findViewById(R.id.btn_excel);
//        Matrix matrix = btn_excel.getMatrix();
//        matrix.postRotate(90, btn_excel.getLeft(), btn_excel.getBottom());
//        btn_excel.invalidate();
    }
}
